@@ -16,16 +16,16 @@ knitr::opts_chunk$set(
 
 rm(dpi)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  install.packages("Coxmos")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  install.packages("devtools")
-#  devtools::install_github("BiostatOmics/Coxmos")
+#  devtools::install_github("BiostatOmics/Coxmos", build_vignettes = TRUE)
 
-## ----setup, eval=FALSE, results = "hide"--------------------------------------
-#  # load Coxmos
-#  library(Coxmos)
+## ----setup, results = "hide"--------------------------------------------------
+# load Coxmos
+library(Coxmos)
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  # install.packages("RColorConesa")
@@ -168,7 +168,7 @@ splsicox_model
 
 ## ---- warning==FALSE, eval=FALSE----------------------------------------------
 #  # run cv.splsdrcox
-#  cv.splsdrcox_res <- cv.splsdrcox(X = X_train, Y = Y_train,
+#  cv.splsdrcox_penalty_res <- cv.splsdrcox_penalty(X = X_train, Y = Y_train,
 #                                   max.ncomp = 2, penalty.list = c(0.5, 0.9),
 #                                   n_run = 2, k_folds = 5,
 #                                   x.center = T, x.scale = F,
@@ -181,26 +181,26 @@ splsicox_model
 #                                   PARALLEL = F, verbose = F, seed = 123)
 
 ## ---- eval=FALSE--------------------------------------------------------------
-#  cv.splsdrcox_res
+#  cv.splsdrcox_penalty_res
 
 ## ---- fig.small=T, warning=F, eval=FALSE--------------------------------------
 #  # plot cv.plsicox
-#  cv.splsdrcox_res$plot_AUC
+#  cv.splsdrcox_penalty_res$plot_AUC
 
 ## -----------------------------------------------------------------------------
-splsdrcox_model <- splsdrcox(X = X_train, Y = Y_train, 
-                             n.comp = 2, #cv.splsdrcox_res$opt.comp, 
-                             penalty = 0.5, #cv.splsdrcox_res$opt.eta,
+splsdrcox_penalty_model <- splsdrcox_penalty(X = X_train, Y = Y_train, 
+                             n.comp = 2, #cv.splsdrcox_penalty_res$opt.comp, 
+                             penalty = 0.5, #cv.splsdrcox_penalty_res$opt.eta,
                              x.center = T, x.scale = F,
                              remove_near_zero_variance = T, remove_zero_variance = F, toKeep.zv = NULL,
                              remove_non_significant = T,
                              MIN_EPV = 5, returnData = T, verbose = F)
 
-splsdrcox_model
+splsdrcox_penalty_model
 
 ## ---- warning=FALSE, eval=FALSE-----------------------------------------------
 #  # run cv.splsdrcox
-#  cv.splsdrcox_dynamic_res <- cv.splsdrcox_dynamic(X = X_train, Y = Y_train,
+#  cv.splsdrcox_dynamic_res <- cv.splsdrcox(X = X_train, Y = Y_train,
 #                                                   max.ncomp = 2, vector = NULL,
 #                                                   MIN_NVAR = 10, MAX_NVAR = 400,
 #                                                   n.cut_points = 10, EVAL_METHOD = "AUC",
@@ -221,12 +221,12 @@ splsdrcox_model
 #  cv.splsdrcox_dynamic_res
 
 ## -----------------------------------------------------------------------------
-splsdrcox_dynamic_model <- splsdrcox_dynamic(X = X_train, Y = Y_train, 
+splsdrcox_dynamic_model <- splsdrcox(X = X_train, Y = Y_train, 
                                              n.comp = 2, #cv.splsdrcox_dynamic_res$opt.comp,
                                              vector = 369, #cv.splsdrcox_dynamic_res$opt.nvar,
                                              x.center = T, x.scale = F,
                                              remove_near_zero_variance = T, remove_zero_variance = F, toKeep.zv = NULL,
-                                             MIN_NVAR = 10, MAX_NVAR = 1000, n.cut_points = 5,
+                                             MIN_NVAR = 10, MAX_NVAR = NULL, n.cut_points = 5,
                                              MIN_AUC_INCREASE = 0.01,
                                              EVAL_METHOD = "AUC", pred.method = "cenROC", max.iter = 200,
                                              remove_non_significant = T, 
@@ -236,7 +236,7 @@ splsdrcox_dynamic_model
 
 ## ---- warning=FALSE, eval=FALSE-----------------------------------------------
 #  # run cv.splsdrcox
-#  cv.splsdacox_dynamic_res <- cv.splsdacox_dynamic(X = X_train, Y = Y_train,
+#  cv.splsdacox_dynamic_res <- cv.splsdacox(X = X_train, Y = Y_train,
 #                                                   max.ncomp = 2, vector = NULL,
 #                                                   MIN_NVAR = 10, MAX_NVAR = 400,
 #                                                   n.cut_points = 10, EVAL_METHOD = "AUC",
@@ -257,12 +257,12 @@ splsdrcox_dynamic_model
 #  cv.splsdacox_dynamic_res
 
 ## -----------------------------------------------------------------------------
-splsdacox_dynamic_model <- splsdacox_dynamic(X = X_train, Y = Y_train, 
+splsdacox_dynamic_model <- splsdacox(X = X_train, Y = Y_train, 
                                              n.comp = 2, #cv.splsdacox_dynamic_res$opt.comp, 
                                              vector = 330, #cv.splsdacox_dynamic_res$opt.nvar,
                                              x.center = T, x.scale = F,
                                              remove_near_zero_variance = T, remove_zero_variance = F, toKeep.zv = NULL,
-                                             MIN_NVAR = 10, MAX_NVAR = 1000, n.cut_points = 5,
+                                             MIN_NVAR = 10, MAX_NVAR = NULL, n.cut_points = 5,
                                              MIN_AUC_INCREASE = 0.01,
                                              EVAL_METHOD = "AUC", pred.method = "cenROC", max.iter = 200,
                                              remove_non_significant = T, 
@@ -273,7 +273,7 @@ splsdacox_dynamic_model
 ## -----------------------------------------------------------------------------
 lst_models <- list("COX-EN" = coxen_model,
                    "sPLS-ICOX" = splsicox_model,
-                   "sPLS-DRCOX" = splsdrcox_model,
+                   "sPLS-DRCOX-Penalty" = splsdrcox_penalty_model,
                    "sPLS-DRCOX-Dynamic" = splsdrcox_dynamic_model,
                    "sPLS-DACOX-Dynamic" = splsdacox_dynamic_model)
 
@@ -303,7 +303,7 @@ lst_eval_results <- plot_evaluation(eval_results, evaluation = "AUC", pred.attr
 lst_eval_results_BRIER <- plot_evaluation(eval_results, evaluation = "Brier", pred.attr = "mean")
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
-lst_eval_results$lst_plots$lineplot.mean
+lst_eval_results$lineplot.mean
 lst_eval_results$lst_plot_comparisons$anova
 
 # lst_eval_results$cenROC$lst_plots$lineplot.mean
@@ -314,8 +314,8 @@ lst_models_time <- list(#cv.coxen_res,
                         coxen_model,
                         #cv.splsicox_res,
                         splsicox_model,
-                        #cv.splsdrcox_res,
-                        splsdrcox_model,
+                        #cv.splsdrcox_penalty_res,
+                        splsdrcox_penalty_model,
                         #cv.splsdrcox_dynamic_res,
                         splsdrcox_dynamic_model,
                         #cv.splsdacox_dynamic_res,
@@ -330,7 +330,7 @@ ggp_time
 
 ## -----------------------------------------------------------------------------
 #lst_forest_plot <- plot_forest.list(lst_models)
-lst_forest_plot <- plot_forest(lst_models$`sPLS-DRCOX`)
+lst_forest_plot <- plot_forest(lst_models$`sPLS-DRCOX-Dynamic`)
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
 #lst_forest_plot$`sPLS-DRCOX`
@@ -338,7 +338,7 @@ lst_forest_plot
 
 ## -----------------------------------------------------------------------------
 #lst_ph_ggplot <- plot_proportionalHazard.list(lst_models)
-lst_ph_ggplot <- plot_proportionalHazard(lst_models$`sPLS-DRCOX`)
+lst_ph_ggplot <- plot_proportionalHazard(lst_models$`sPLS-DRCOX-Dynamic`)
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
 #lst_ph_ggplot$`sPLS-DRCOX`
@@ -346,7 +346,7 @@ lst_ph_ggplot
 
 ## -----------------------------------------------------------------------------
 #density.plots.lp <- plot_cox.event.list(lst_models, type = "lp")
-density.plots.lp <- plot_cox.event(lst_models$`sPLS-DRCOX`, type = "lp")
+density.plots.lp <- plot_cox.event(lst_models$`sPLS-DRCOX-Dynamic`, type = "lp")
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
 # density.plots.lp$`sPLS-DRCOX`$plot.density
@@ -356,14 +356,14 @@ density.plots.lp$plot.density
 density.plots.lp$plot.histogram
 
 ## -----------------------------------------------------------------------------
-ggp_scores <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX`, 
+ggp_scores <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX-Dynamic`, 
                              comp = c(1,2), mode = "scores")
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
 ggp_scores$plot
 
 ## -----------------------------------------------------------------------------
-ggp_loadings <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX`, 
+ggp_loadings <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX-Dynamic`, 
                                comp = c(1,2), mode = "loadings",
                                top = 10) #length from 0,0
 
@@ -371,7 +371,7 @@ ggp_loadings <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX`,
 ggp_loadings$plot
 
 ## -----------------------------------------------------------------------------
-ggp_biplot <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX`, 
+ggp_biplot <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX-Dynamic`, 
                              comp = c(1,2), mode = "biplot",
                              top = 15,
                              only_top = T,
@@ -381,9 +381,9 @@ ggp_biplot <- plot_PLS_Coxmos(model = lst_models$`sPLS-DRCOX`,
 ggp_biplot$plot
 
 ## ---- warning=F---------------------------------------------------------------
-variable_auc_results <- eval_Coxmos_model_per_variable(model = lst_models$`sPLS-DRCOX`, 
-                                                       X_test = lst_models$`sPLS-DRCOX`$X_input, 
-                                                       Y_test = lst_models$`sPLS-DRCOX`$Y_input,
+variable_auc_results <- eval_Coxmos_model_per_variable(model = lst_models$`sPLS-DRCOX-Dynamic`, 
+                                                       X_test = lst_models$`sPLS-DRCOX-Dynamic`$X_input, 
+                                                       Y_test = lst_models$`sPLS-DRCOX-Dynamic`$Y_input,
                                                        pred.method = "cenROC", pred.attr = "mean",
                                                        times = NULL, max_time_points = 15,
                                                        PARALLEL = FALSE)
@@ -399,7 +399,7 @@ variable_auc_plot_train$lst_plots$lineplot.mean
 #                                            zero.rm = T, auto.limits = T, top = 20,
 #                                            show_percentage = T, size_percentage = 2, verbose = F)
 
-ggp.simulated_beta <- plot_pseudobeta(model = lst_models$`sPLS-DRCOX`, 
+ggp.simulated_beta <- plot_pseudobeta(model = lst_models$`sPLS-DRCOX-Dynamic`, 
                                       error.bar = T, onlySig = T, alpha = 0.05, 
                                       zero.rm = T, auto.limits = T, top = 20,
                                       show_percentage = T, size_percentage = 2)
@@ -418,7 +418,7 @@ ggp.simulated_beta$plot
 #                                 only_sig = T, alpha = 0.05)
 
 LST_KM_RES_LP <- getAutoKM(type = "LP",
-                           model = lst_models$`sPLS-DRCOX`,
+                           model = lst_models$`sPLS-DRCOX-Dynamic`,
                            comp = 1:10,
                            top = 10,
                            ori_data = T,
@@ -438,7 +438,7 @@ LST_KM_RES_LP$LST_PLOTS$LP
 #                                  lst_cutoff = lst_cutoff)
 
 lst_cutoff <- getCutoffAutoKM(LST_KM_RES_LP)
-LST_KM_TEST_LP <- getTestKM(model = lst_models$`sPLS-DRCOX`, 
+LST_KM_TEST_LP <- getTestKM(model = lst_models$`sPLS-DRCOX-Dynamic`, 
                             X_test = X_test, Y_test = Y_test, 
                             type = "LP",
                             BREAKTIME = NULL, n.breaks = 20,
@@ -459,7 +459,7 @@ LST_KM_TEST_LP
 #                                   only_sig = T, alpha = 0.05)
 
 LST_KM_RES_COMP <- getAutoKM(type = "COMP",
-                             model = lst_models$`sPLS-DRCOX`,
+                             model = lst_models$`sPLS-DRCOX-Dynamic`,
                              comp = 1:10,
                              top = 10,
                              ori_data = T,
@@ -483,7 +483,7 @@ LST_KM_RES_COMP$LST_PLOTS$comp_2
 #                                    lst_cutoff = lst_cutoff)
 
 lst_cutoff <- getCutoffAutoKM(LST_KM_RES_COMP)
-LST_KM_TEST_COMP <- getTestKM(model = lst_models$`sPLS-DRCOX`, 
+LST_KM_TEST_COMP <- getTestKM(model = lst_models$`sPLS-DRCOX-Dynamic`, 
                               X_test = X_test, Y_test = Y_test, 
                               type = "COMP",
                               BREAKTIME = NULL, n.breaks = 20,
@@ -507,7 +507,7 @@ LST_KM_TEST_COMP$comp_2
 #                                  only_sig = T, alpha = 0.05)
 
 LST_KM_RES_VAR <- getAutoKM(type = "VAR",
-                            model = lst_models$`sPLS-DRCOX`,
+                            model = lst_models$`sPLS-DRCOX-Dynamic`,
                             comp = 1:10, #select how many components you want to compute for the pseudo beta
                             top = 10,
                             ori_data = T, #original data selected
@@ -515,11 +515,8 @@ LST_KM_RES_VAR <- getAutoKM(type = "VAR",
                             only_sig = T, alpha = 0.05)
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
-# LST_KM_RES_VAR$`sPLS-DRCOX`$LST_PLOTS$`840`
-# LST_KM_RES_VAR$`sPLS-DRCOX`$LST_PLOTS$`3897`
-
-LST_KM_RES_VAR$LST_PLOTS$`840`
-LST_KM_RES_VAR$LST_PLOTS$`3897`
+LST_KM_RES_VAR$LST_PLOTS$var_840
+LST_KM_RES_VAR$LST_PLOTS$var_3897
 
 ## -----------------------------------------------------------------------------
 # lst_cutoff <- getCutoffAutoKM.list(LST_KM_RES_VAR)
@@ -530,18 +527,15 @@ LST_KM_RES_VAR$LST_PLOTS$`3897`
 #                                   lst_cutoff = lst_cutoff)
 
 lst_cutoff <- getCutoffAutoKM(LST_KM_RES_VAR)
-LST_KM_TEST_VAR <- getTestKM(model = lst_models$`sPLS-DRCOX`, 
+LST_KM_TEST_VAR <- getTestKM(model = lst_models$`sPLS-DRCOX-Dynamic`, 
                              X_test = X_test, Y_test = Y_test, 
                              type = "VAR", ori_data = T,
                              BREAKTIME = NULL, n.breaks = 20,
                              cutoff = lst_cutoff)
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
-# LST_KM_TEST_VAR$`sPLS-DRCOX`$`840`
-# LST_KM_TEST_VAR$`sPLS-DRCOX`$`3897`
-
-LST_KM_TEST_VAR$`840`
-LST_KM_TEST_VAR$`3897`
+LST_KM_TEST_VAR$var_840
+LST_KM_TEST_VAR$var_3897
 
 ## -----------------------------------------------------------------------------
 new_pat <- X_test[1,,drop=F]
@@ -555,7 +549,7 @@ knitr::kable(Y_test[rownames(new_pat),])
 #                                                              error.bar = T, onlySig = T, alpha = 0.05,
 #                                                              zero.rm = T, auto.limits = T, show.betas = T, top = 20)
 
-ggp.simulated_beta_newObs <- plot_pseudobeta_newObservation(model = lst_models$`sPLS-DRCOX`,
+ggp.simulated_beta_newObs <- plot_pseudobeta_newObservation(model = lst_models$`sPLS-DRCOX-Dynamic`,
                                                         new_observation = new_pat,
                                                         error.bar = T, onlySig = T, alpha = 0.05,
                                                         zero.rm = T, auto.limits = T, show.betas = T, top = 20)
@@ -567,7 +561,7 @@ ggp.simulated_beta_newObs$plot
 
 ## -----------------------------------------------------------------------------
 pat_density <- plot_observation.eventDensity(observation = new_pat,
-                                             model = lst_models$`sPLS-DRCOX`,
+                                             model = lst_models$`sPLS-DRCOX-Dynamic`,
                                              time = NULL, 
                                              type = "lp")
 
@@ -576,7 +570,7 @@ pat_density
 
 ## -----------------------------------------------------------------------------
 pat_histogram <- plot_observation.eventHistogram(observation = new_pat, 
-                                                 model = lst_models$`sPLS-DRCOX`, 
+                                                 model = lst_models$`sPLS-DRCOX-Dynamic`, 
                                                  time = NULL, 
                                                  type = "lp")
 
@@ -592,13 +586,13 @@ knitr::kable(Y_test[1:5,])
 #                                                     error.bar = T, zero.rm = T, onlySig = T, 
 #                                                     alpha = 0.05, top = 10)
 
-lst_cox.comparison <- plot_LP.multipleObservations(model = lst_models$`sPLS-DRCOX`,
+lst_cox.comparison <- plot_LP.multipleObservations(model = lst_models$`sPLS-DRCOX-Dynamic`,
                                                    new_observations = X_test[1:5,],
                                                    error.bar = T, zero.rm = T, onlySig = T, 
                                                    alpha = 0.05, top = 10)
 
 ## ---- fig.small=T, warning=F--------------------------------------------------
-# lst_cox.comparison$`sPLS-DRCOX`$plot
+# lst_cox.comparison$`sPLS-DRCOX-Dynamic`$plot
 
 lst_cox.comparison$plot
 
